You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by tn...@apache.org on 2012/02/03 18:38:02 UTC

svn commit: r1240253 - in /commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode: MultistepIntegrator.java ParameterConfiguration.java ParameterizedWrapper.java

Author: tn
Date: Fri Feb  3 17:38:02 2012
New Revision: 1240253

URL: http://svn.apache.org/viewvc?rev=1240253&view=rev
Log:
Fixed checkstyle and javadoc warnings in package ode

Modified:
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/MultistepIntegrator.java
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterConfiguration.java
    commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterizedWrapper.java

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/MultistepIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/MultistepIntegrator.java?rev=1240253&r1=1240252&r2=1240253&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/MultistepIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/MultistepIntegrator.java Fri Feb  3 17:38:02 2012
@@ -382,7 +382,7 @@ public abstract class MultistepIntegrato
         }
 
         /** {@inheritDoc} */
-        public void init(double t0, double[] y0, double t) {
+        public void init(double t0, double[] y0, double time) {
             // nothing to do
         }
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterConfiguration.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterConfiguration.java?rev=1240253&r1=1240252&r2=1240253&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterizedWrapper.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterizedWrapper.java Fri Feb  3 17:38:02 2012
@@ -40,10 +40,18 @@ class ParameterizedWrapper implements Pa
         this.fode = ode;
     }
 
+    /** Get the dimension of the underlying FODE.
+     * @return dimension of the underlying FODE
+     */
     public int getDimension() {
         return fode.getDimension();
     }
 
+    /** Get the current time derivative of the state vector of the underlying FODE.
+     * @param t current value of the independent <I>time</I> variable
+     * @param y array containing the current value of the state vector
+     * @param yDot placeholder array where to put the time derivative of the state vector
+     */
     public void computeDerivatives(double t, double[] y, double[] yDot) {
         fode.computeDerivatives(t, y, yDot);
     }
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterConfiguration.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterConfiguration.java Fri Feb  3 17:38:02 2012
@@ -58,10 +58,10 @@ class ParameterConfiguration implements 
     }
 
     /** Set parameter step.
      * @param hP parameter step
      */
-    public void setHP(final double hP) {
-        this.hP = hP;
+    public void setHP(final double hParam) {
+        this.hP = hParam;
     }
 
 }
@@ -58,10 +58,10 @@ class ParameterConfiguration implements 
 
     /** Set parameter step.
-     * @param hP parameter step
+     * @param hParam parameter step
      */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterizedWrapper.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math/ode/ParameterizedWrapper.java?rev=1240253&r1=1240252&r2=1240253&view=diff
==============================================================================